==> haskell-http2-1.4.4-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http2/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.4.4
id: http2-1.4.4-629cb0cc25ee9167eedb1ea6326b7044
key: http2_LpjBogTt74vAWdoTZ0FuGZ
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP/2.0 library including frames and HPACK
description:
    HTTP/2.0 library including frames and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HTTP2 Network.HTTP2.Priority
hidden-modules: Network.HPACK.Builder Network.HPACK.Builder.Word8
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.From
                Network.HPACK.HeaderBlock.HeaderField
                Network.HPACK.HeaderBlock.Integer Network.HPACK.HeaderBlock.String
                Network.HPACK.HeaderBlock.To Network.HPACK.Table
                Network.HPACK.Table.Dynamic Network.HPACK.Table.Entry
                Network.HPACK.Table.RevIndex Network.HPACK.Table.Static
                Network.HPACK.Types Network.HTTP2.Decode Network.HTTP2.Encode
                Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
                Network.HTTP2.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.4.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.4.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/http2-1.4.4
hs-libraries: HShttp2-1.4.4-LpjBogTt74vAWdoTZ0FuGZ
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    psqueues-0.2.0.3-84f6eba20019e2166992e8a1868d0a2e
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-1.4.4-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http2/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.4.4
id: http2-1.4.4-d76cf9fba067cc3fa61ea943ef4340ee
key: http2_EvTeNGoKRrV5vUZO3DRyiw
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP/2.0 library including frames and HPACK
description:
    HTTP/2.0 library including frames and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HTTP2 Network.HTTP2.Priority
hidden-modules: Network.HPACK.Builder Network.HPACK.Builder.Word8
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.From
                Network.HPACK.HeaderBlock.HeaderField
                Network.HPACK.HeaderBlock.Integer Network.HPACK.HeaderBlock.String
                Network.HPACK.HeaderBlock.To Network.HPACK.Table
                Network.HPACK.Table.Dynamic Network.HPACK.Table.Entry
                Network.HPACK.Table.RevIndex Network.HPACK.Table.Static
                Network.HPACK.Types Network.HTTP2.Decode Network.HTTP2.Encode
                Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
                Network.HTTP2.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.4.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.4.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/http2-1.4.4
hs-libraries: HShttp2-1.4.4-EvTeNGoKRrV5vUZO3DRyiw
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    psqueues-0.2.1.0-4c5a2c05436d7e9757d8e128887dcec2
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
